==> phpcore-7.0.0.tgz: package/src/Class/ClassPromoter.js <==
/*
 * PHPCore - PHP environment runtime components
 * Copyright (c) Dan Phillimore (asmblah)
 * https://github.com/uniter/phpcore/
 *
 * Released under the MIT license
 * https://github.com/uniter/phpcore/raw/master/MIT-LICENSE.txt
 */

'use strict';

var _ = require('microdash');

/**
 * Creates a class from its definition
 *
 * @param {ClassFactory} classFactory
 * @param {MethodPromoter} methodPromoter
 * @constructor
 */
function ClassPromoter(
    classFactory,
    methodPromoter
) {
    /**
     * @type {ClassFactory}
     */
    this.classFactory = classFactory;
    /**
     * @type {MethodPromoter}
     */
    this.methodPromoter = methodPromoter;
}

_.extend(ClassPromoter.prototype, {
    /**
     * Promotes a ClassDefinition to a Class
     *
     * @param {ClassDefinition} classDefinition
     * @returns {Class} Returns the internal Class instance created
     */
    promoteDefinition: function (classDefinition) {
        var promoter = this,
            InternalClass = classDefinition.getInternalClass(),
            sharedMethodData = classDefinition.getMethodData(),
            namespaceScope = classDefinition.getNamespaceScope(),
            classObject = promoter.classFactory.createClass(
                classDefinition.getName(),
                classDefinition.getNamespace(),
                namespaceScope,
                classDefinition.getConstructorName(),
                InternalClass,
                classDefinition.getRootInternalPrototype(),
                classDefinition.getInstanceProperties(),
                classDefinition.getStaticProperties(),
                classDefinition.getConstants(),
                classDefinition.getSuperClass(),
                classDefinition.getInterfaces(),
                classDefinition.getValueCoercer()
            );

        _.forOwn(classDefinition.getMethods(), function (methodDefinition, methodName) {
            InternalClass.prototype[methodName] = promoter.methodPromoter.promote(
                methodName,
                methodDefinition,
                classObject,
                namespaceScope,
                sharedMethodData
            );
        });

        // Enable fetching the original class object (which may be different from the current class,
        // if the method was inherited) via methods.
        sharedMethodData.classObject = classObject;

        return classObject;
    }
});

module.exports = ClassPromoter;

==> phpcore-8.0.1.tgz: package/src/Class/ClassPromoter.js <==
/*
 * PHPCore - PHP environment runtime components
 * Copyright (c) Dan Phillimore (asmblah)
 * https://github.com/uniter/phpcore/
 *
 * Released under the MIT license
 * https://github.com/uniter/phpcore/raw/master/MIT-LICENSE.txt
 */

'use strict';

var _ = require('microdash');

/**
 * Creates a class from its definition
 *
 * @param {ClassFactory} classFactory
 * @param {MethodPromoter} methodPromoter
 * @constructor
 */
function ClassPromoter(
    classFactory,
    methodPromoter
) {
    /**
     * @type {ClassFactory}
     */
    this.classFactory = classFactory;
    /**
     * @type {MethodPromoter}
     */
    this.methodPromoter = methodPromoter;
}

_.extend(ClassPromoter.prototype, {
    /**
     * Promotes a ClassDefinition to a Class
     *
     * @param {ClassDefinition} classDefinition
     * @returns {Class} Returns the internal Class instance created
     */
    promoteDefinition: function (classDefinition) {
        var promoter = this,
            InternalClass = classDefinition.getInternalClass(),
            sharedMethodData = classDefinition.getMethodData(),
            namespaceScope = classDefinition.getNamespaceScope(),
            classObject = promoter.classFactory.createClass(
                classDefinition.getName(),
                classDefinition.getNamespace(),
                namespaceScope,
                classDefinition.getConstructorName(),
                InternalClass,
                classDefinition.getRootInternalPrototype(),
                classDefinition.getInstanceProperties(),
                classDefinition.getStaticProperties(),
                classDefinition.getConstants(),
                classDefinition.getSuperClass(),
                classDefinition.getInterfaces(),
                classDefinition.getValueCoercer(),
                classDefinition.getMethodCaller()
            );

        _.forOwn(classDefinition.getMethods(), function (methodDefinition, methodName) {
            InternalClass.prototype[methodName] = promoter.methodPromoter.promote(
                methodName,
                methodDefinition,
                classObject,
                namespaceScope,
                sharedMethodData
            );
        });

        // Enable fetching the original class object (which may be different from the current class,
        // if the method was inherited) via methods.
        sharedMethodData.classObject = classObject;

        return classObject;
    }
});

module.exports = ClassPromoter;
